{% for group in groups %}
    <div class="{{ group.div_css_class }}" style="{{ group.div_css }}"{% if group.div_id %} id="{{ group.div_id }}"{% endif %}>
        {% if group.group_title %}<h5>{{ group.group_title }}</h5>{% endif %}
        {% for card in group.cards %}
        {{ card.render }}
        {% endfor %}
    </div>
    {% if group.script %}<script>{{ group.script|safe }}</script>{% endif %}
{% endfor %}
<script>$(function(){$('[data-toggle="tooltip"]').tooltip({container:'body'});$('[data-toggle="popover"]').popover({container:'body'})})</script>