{{ card.tab_menu.render }}
<div class="{{ card_body_css_class }}{% if card.enable_collapse %} collapse{% if not card.collapsed %} show{% endif %}{% endif %}" id="{{ card.code }}_body">
    <div class="list-group">
        <table class="{{ table_css_class }}">
            {% for row in card.rows %}
                <tr>
                    {% if row.type == 'html' %}{% if not row.exclude_td %}<td class="{{ table_td_css_class }}"{% if row.colspan %} colspan="{{ row.colspan }}"{% endif %} {% if row.rowspan %} rowspan="{{ row.rowspan }}"{% endif %}>{{ row.html|safe }}</td>{% else %}{{ row.html|safe }}{% endif %}{% else %}
                    {% for entry in row.entries %}
                        {% if entry.row_style_html %}{{ entry.row_style_html|safe }}{% else %}
                        {% if entry.separator %}</tr><tr><td colspan="2"><hr class="my-1"></td></tr><tr>{% endif %}
                        {% if forloop.first %}{% if entry.label_td %}<td>{{ entry.label|safe }}</td>{% else %}<th class="{{ table_th_css_class }}">{{ entry.label|safe }}</th>{% endif %}{% endif %}
                        {% if entry.value_th %}<th{% else %}<td class="{{ table_td_css_class }}"{% endif %}{% if entry.colspan %} colspan="{{ entry.colspan }}"{% endif %}{% if entry.rowspan %} rowspan="{{ entry.rowspan }}"{% endif %}{% if entry.popover %} tabindex="0" data-toggle="popover" data-trigger="focus" title="{{ entry.popover.title }}" data-content="{{ entry.popover.content }}"{% elif entry.tooltip %} data-toggle="tooltip" title="{{ entry.tooltip }}"{% endif %}>{% if entry.link %}
                            <a class="list-group-item cards-list-group-item" href="{{ entry.link }}">{% endif %}{% if entry.progress_bar %}
                            <div class="progress" style="height:20px"><div class="progress-bar {{ entry.progress_bar }}" style="width:{{ entry.html }}%">{{ entry.html }}%</div></div>
                        {% elif entry.image %}
                            <img src="{{ entry.html }}" style="height:{{ entry.image }};object-fit:cover" alt="">
                        {% elif entry.rating %}
                            {% for i in entry.rating_range %}<i class="{% if forloop.counter <= entry.html %}fas{% else %}far{% endif %} fa-star text-warning"></i>{% endfor %}
                        {% else %}{% if entry.status_dot %}<span style="display:inline-block;width:10px;height:10px;border-radius:50%;background:{{ entry.status_dot }};margin-right:6px"></span>{% endif %}{% if entry.icon %}<i class="{{ entry.icon }}"></i> {% endif %}{% if entry.value_link %}<a href="{{ entry.value_link }}">{% endif %}
                            {% if entry.multiple_lines %}
                                {% for x in entry.html %}
                                    {{ entry.css_class }}">{% if entry.prefix %}{{ entry.prefix }}{% endif %}{% if entry.badge %}<span class="badge {{ entry.badge }}">{% endif %}{{ x|safe }}{% if entry.badge %}</span>{% endif %}{% if entry.suffix %}{{ entry.suffix }}{% endif %}<br/>
                                {% endfor %}
                            {% else %}
                                {% if entry.prefix %}{{ entry.prefix }}{% endif %}{% if entry.badge %}<span class="badge {{ entry.badge }}">{% endif %}{% if entry.old_value %}<del class="text-danger">{{ entry.old_value }}</del> <i class="fas fa-arrow-right text-muted" style="font-size:0.7em"></i> <span class="text-success">{{ entry.html|safe }}</span>{% else %}{{ entry.html|safe }}{% endif %}{% if entry.badge %}</span>{% endif %}{% if entry.suffix %}{{ entry.suffix }}{% endif %}
                            {% endif %}
                        {% if entry.value_link %}</a>{% endif %}{% endif %}{% if entry.copy_to_clipboard %} <button class="btn btn-sm btn-link p-0 ms-1" onclick="navigator.clipboard.writeText('{{ entry.html|escapejs }}')"><i class="fas fa-copy"></i></button>{% endif %}{% if entry.help_text %}<br><small class="text-muted">{{ entry.help_text }}</small>{% endif %}{% if entry.link %}</a>{% endif %}{% if entry.value_th %}</th>{% else %}</td>{% endif %}
                        {% endif %}
                    {% endfor %}{% endif %}</tr>
            {% endfor %}
        </table>
    </div>
</div>